@@ -11,11 +11,16 @@ def main():
         bool_list = sys.argv[2:]
         for f in t.get_names(t.parse(bool_list)):
             sys.stdout.write(f + "\n")
-    elif sys.argv[1] == "add":
+    elif sys.argv[1] == "tag":
         file_name = sys.argv[2]
         tags = sys.argv[3:]
         for tag in tags:
             t.tag_file(file_name, tag)
+    elif sys.argv[1] == "untag":
+        file_name = sys.argv[2]
+        tags = sys.argv[3:]
+        for tag in tags:
+            t.untag_file(file_name, tag)
     elif sys.argv[1] == "rmtag":
         tag = sys.argv[2]
         t.delete_tag(tag)
